@@ -24,8 +24,6 @@
 
 #include "WaveformGenerator.h"
 
-#include "Dac.h"
-
 /*
  * This fixes tests
  *  SID/wb_testsuite/noise_writeback_check_8_to_C_old
@@ -81,8 +79,6 @@ const unsigned int SHIFT_REGISTER_RESET_6581R4 = 2150000;
 const unsigned int SHIFT_REGISTER_RESET_8580R5 =  986000;
 const unsigned int SHIFT_REGISTER_FADE_8580R5  =  314300;
 
-const int DAC_BITS = 12;
-
 /*
  * This is what happens when the lfsr is clocked:
  *
@@ -174,22 +170,6 @@ void WaveformGenerator::setWaveformModels(matrix_t* models)
     model_wave = models;
 }
 
-void WaveformGenerator::setChipModel(ChipModel chipModel)
-{
-    is6581 = chipModel == MOS6581;
-
-    Dac dacBuilder(DAC_BITS);
-    dacBuilder.kinkedDac(chipModel);
-
-    const double offset = dacBuilder.getOutput(is6581 ? 0x380 : 0x9c0);
-
-    for (unsigned int i = 0; i < (1 << DAC_BITS); i++)
-    {
-        const double dacValue = dacBuilder.getOutput(i);
-        dac[i] = static_cast<float>(dacValue - offset);
-    }
-}
-
 void WaveformGenerator::synchronize(WaveformGenerator* syncDest, const WaveformGenerator* syncSource) const
 {
     // A special case occurs when a sync source is synced itself on the same
